@@ -2,7 +2,7 @@
 
 from numpy import (
     arcsin, arctan2, array, cos, einsum, finfo, float64,
-    full_like, load, rollaxis, sin, sqrt,
+    full_like, load, nan, rollaxis, sin, sqrt, where,
 )
 from pkgutil import get_data
 from skyfield.constants import tau
@@ -14,6 +14,11 @@ class A(object):
     __getitem__ = array
 A = A()
 
+def sqrt_nan(n):
+    """Return the square root of ``n``, or ``nan`` if ``n < 0``."""
+    # (See design/sqrt_nan.py for a speed comparison of approaches.)
+    return where(n < 0.0, nan, sqrt(abs(n)))
+
 def dots(v, u):
     """Given one or more vectors in `v` and `u`, return their dot products.
 
@@ -153,9 +158,10 @@ def angular_velocity_matrix(angular_velocity_vector):
 def _to_array(value):
     """Convert plain Python sequences into NumPy arrays.
 
-    This helps Skyfield endpoints convert caller-provided tuples and
-    lists into NumPy arrays.  If the ``value`` is not a sequence, then
-    it is coerced to a Numpy float object, but not an actual array.
+    This lets users pass plain old Python lists and tuples to Skyfield,
+    instead of always having to remember to build NumPy arrays.  We pass
+    any kind of generic sequence to the NumPy ``array()`` constructor
+    and wrap any other kind of value in a NumPy ``float64`` object.
 
     """
     if hasattr(value, 'shape'):
